Module binance

Module binance 

BinanceSpot & BinanceFuturesUsd Connector and StreamSelector implementations.

Modules

book
OrderBook types common to both BinanceSpot and BinanceFuturesUsd.
channel
Defines the type that translates a Barter Subscription into an exchange Connector specific channel used for generating Connector::requests.
futures
ExchangeServer and StreamSelector implementations for BinanceFuturesUsd.
market
Defines the type that translates a Barter Subscription into an exchange Connector specific market used for generating Connector::requests.
spot
ExchangeServer and StreamSelector implementations for BinanceSpot.
subscription
Subscription response type and response Validator common to both BinanceSpot and BinanceFuturesUsd.
trade
Public trade types common to both BinanceSpot and BinanceFuturesUsd.

Structs

Binance
Generic Binance<Server> exchange.

Type Aliases

BinanceWsStream
Convenient type alias for a Binance ExchangeWsStream using WebSocketSerdeParser.