pub struct BitfinexMarket(pub SmolStr);Expand description
Type that defines how to translate a Barter Subscription into a
Bitfinex market that can be subscribed to.
See docs: https://docs.bitfinex.com/docs/ws-public
Tuple Fields
0: SmolStrTrait Implementations
Sourceimpl AsRef<str> for BitfinexMarket
impl AsRef<str> for BitfinexMarket
Sourceimpl Clone for BitfinexMarket
impl Clone for BitfinexMarket
Sourcefn clone(&self) -> BitfinexMarket
fn clone(&self) -> BitfinexMarket
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BitfinexMarket
impl Debug for BitfinexMarket
Sourceimpl<'de> Deserialize<'de> for BitfinexMarket
impl<'de> Deserialize<'de> for BitfinexMarket
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for BitfinexMarket
impl Hash for BitfinexMarket
Sourceimpl<InstrumentKey, Kind> Identifier<BitfinexMarket> for Subscription<Bitfinex, Keyed<InstrumentKey, MarketDataInstrument>, Kind>
impl<InstrumentKey, Kind> Identifier<BitfinexMarket> for Subscription<Bitfinex, Keyed<InstrumentKey, MarketDataInstrument>, Kind>
fn id(&self) -> BitfinexMarket
Sourceimpl<Kind> Identifier<BitfinexMarket> for Subscription<Bitfinex, MarketDataInstrument, Kind>
impl<Kind> Identifier<BitfinexMarket> for Subscription<Bitfinex, MarketDataInstrument, Kind>
fn id(&self) -> BitfinexMarket
Sourceimpl<InstrumentKey, Kind> Identifier<BitfinexMarket> for Subscription<Bitfinex, MarketInstrumentData<InstrumentKey>, Kind>
impl<InstrumentKey, Kind> Identifier<BitfinexMarket> for Subscription<Bitfinex, MarketInstrumentData<InstrumentKey>, Kind>
fn id(&self) -> BitfinexMarket
Sourceimpl Ord for BitfinexMarket
impl Ord for BitfinexMarket
Sourcefn cmp(&self, other: &BitfinexMarket) -> Ordering
fn cmp(&self, other: &BitfinexMarket) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for BitfinexMarket
impl PartialEq for BitfinexMarket
Sourcefn eq(&self, other: &BitfinexMarket) -> bool
fn eq(&self, other: &BitfinexMarket) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for BitfinexMarket
impl PartialOrd for BitfinexMarket
Sourceimpl Serialize for BitfinexMarket
impl Serialize for BitfinexMarket
impl Eq for BitfinexMarket
impl StructuralPartialEq for BitfinexMarket