Subscription response types and response
Validator for Bitfinex.
Structs
- Bitfinex
Channel Id Bitfinexchannel identifier that is used to identify the subscription associated with incoming events. See the module level “SubscriptionId” documentation notes for more details.- Bitfinex
Error Bitfinexerror message that is received if aBitfinexSubResponseindicates a WebSocket subscription failure.- Bitfinex
Platform Status Bitfinexplatform status message containing the server we are connecting to, the version of the API, and if it is in maintenance mode.- Bitfinex
SubResponse Bitfinexsubscription success response variants for each channel.
Enums
- Bitfinex
Platform Event Bitfinexplatform event detailing the variants expected to be received while connecting and subscribing.- Status
BitfinexplatformStatusindicating if the API is in maintenance mode.