pub struct BitfinexTrade {
pub id: u64,
pub time: DateTime<Utc>,
pub side: Side,
pub price: Decimal,
pub amount: Decimal,
}Expand description
Bitfinex real-time trade message.
Raw Payload Examples
Format: [ID, TIME, AMOUNT, PRICE],
where +/- of amount indicates Side
See docs: https://docs.bitfinex.com/reference/ws-public-trades
Side::Buy Trade
See docs: https://docs.bitfinex.com/reference/ws-public-trades
[420191,"te",[1225484398,1665452200022,0.08980641,19027.02807752]]Side::Sell Trade
See docs: https://docs.bitfinex.com/reference/ws-public-trades
[420191,"te",[1225484398,1665452200022,-0.08980641,19027.02807752]]Notes:
Bitfinextrades subscriptions results in receiving tag=“te” & tag=“tu” trades, both of which are identical.- “te” trades arrive marginally faster.
- Therefore, tag=“tu” trades are filtered out and considered only as additional Heartbeats.
See docs: https://docs.bitfinex.com/reference/ws-public-trades
Fields
id: u64time: DateTime<Utc>side: Sideprice: Decimalamount: DecimalTrait Implementations
Sourceimpl Clone for BitfinexTrade
impl Clone for BitfinexTrade
Sourcefn clone(&self) -> BitfinexTrade
fn clone(&self) -> BitfinexTrade
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BitfinexTrade
impl Debug for BitfinexTrade
Sourceimpl<'de> Deserialize<'de> for BitfinexTrade
impl<'de> Deserialize<'de> for BitfinexTrade
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for BitfinexTrade
impl PartialEq for BitfinexTrade
Sourcefn eq(&self, other: &BitfinexTrade) -> bool
fn eq(&self, other: &BitfinexTrade) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for BitfinexTrade
impl PartialOrd for BitfinexTrade
Sourceimpl Serialize for BitfinexTrade
impl Serialize for BitfinexTrade
impl Copy for BitfinexTrade
impl StructuralPartialEq for BitfinexTrade