pub struct BitmexMarket(pub SmolStr);Expand description
Type that defines how to translate a Barter Subscription into a Bitmex
market that can be subscribed to.
See docs: https://www.bitmex.com/app/wsAPI
Tuple Fields
0: SmolStrTrait Implementations
Sourceimpl AsRef<str> for BitmexMarket
impl AsRef<str> for BitmexMarket
Sourceimpl Clone for BitmexMarket
impl Clone for BitmexMarket
Sourcefn clone(&self) -> BitmexMarket
fn clone(&self) -> BitmexMarket
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BitmexMarket
impl Debug for BitmexMarket
Sourceimpl<'de> Deserialize<'de> for BitmexMarket
impl<'de> Deserialize<'de> for BitmexMarket
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for BitmexMarket
impl Hash for BitmexMarket
Sourceimpl<InstrumentKey, Kind> Identifier<BitmexMarket> for Subscription<Bitmex, Keyed<InstrumentKey, MarketDataInstrument>, Kind>
impl<InstrumentKey, Kind> Identifier<BitmexMarket> for Subscription<Bitmex, Keyed<InstrumentKey, MarketDataInstrument>, Kind>
fn id(&self) -> BitmexMarket
Sourceimpl<Kind> Identifier<BitmexMarket> for Subscription<Bitmex, MarketDataInstrument, Kind>
impl<Kind> Identifier<BitmexMarket> for Subscription<Bitmex, MarketDataInstrument, Kind>
fn id(&self) -> BitmexMarket
Sourceimpl<InstrumentKey, Kind> Identifier<BitmexMarket> for Subscription<Bitmex, MarketInstrumentData<InstrumentKey>, Kind>
impl<InstrumentKey, Kind> Identifier<BitmexMarket> for Subscription<Bitmex, MarketInstrumentData<InstrumentKey>, Kind>
fn id(&self) -> BitmexMarket
Sourceimpl Ord for BitmexMarket
impl Ord for BitmexMarket
Sourcefn cmp(&self, other: &BitmexMarket) -> Ordering
fn cmp(&self, other: &BitmexMarket) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for BitmexMarket
impl PartialEq for BitmexMarket
Sourcefn eq(&self, other: &BitmexMarket) -> bool
fn eq(&self, other: &BitmexMarket) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for BitmexMarket
impl PartialOrd for BitmexMarket
Sourceimpl Serialize for BitmexMarket
impl Serialize for BitmexMarket
impl Eq for BitmexMarket
impl StructuralPartialEq for BitmexMarket