Module bybit

Module bybit 

Bybit [‘Connector’] and [‘StreamSelector’] implementation

Modules

book
Orderbook types common to both BybitSpot and BybitFuturesUsd.
channel
Defines the type that translates a Barter Subscription into an exchange Connector specific channel used for generating Connector::requests.
futures
ExchangeServer and StreamSelector implementations for BybitFuturesUsd.
market
Defines the type that translates a Barter Subscription into an exchange Connector specific market used for generating Connector::requests.
message
Generic BybitPayload<T> type common to BybitSpot
spot
ExchangeServer and StreamSelector implementations for BybitSpot.
subscription
Subscription response type and response Validator common to both BybitSpot and BybitFuturesUsd.
trade
Public trade types common to both BybitSpot and BybitFuturesUsd.

Structs

Bybit
Generic Bybit<Server> exchange.

Type Aliases

BybitWsStream
Convenient type alias for a Bybit ExchangeWsStream using WebSocketSerdeParser.