BybitChannel

Struct BybitChannel 

pub struct BybitChannel(pub &'static str);
Type that defines how to translate a Barter Subscription into a Bybit channel to be subscribed to.

See docs: https://bybit-exchange.github.io/docs/v5/ws/connect

Tuple Fields

0: &'static str

Implementations

Source

impl BybitChannel

pub const TRADES: Self

pub const ORDER_BOOK_L1: Self

Bybit real-time OrderBook Level1 (top of books) channel name.

See docs: https://bybit-exchange.github.io/docs/v5/websocket/public/orderbook

pub const ORDER_BOOK_L2: Self

Bybit OrderBook Level2 channel name (20ms delta updates).

See docs: https://bybit-exchange.github.io/docs/v5/websocket/public/orderbook