pub struct BybitMarket(pub SmolStr);Expand description
Type that defines how to translate a Barter Subscription into a Bybit
market that can be subscribed to.
See docs: https://bybit-exchange.github.io/docs/v5/ws/connect
Tuple Fields
0: SmolStrTrait Implementations
Sourceimpl AsRef<str> for BybitMarket
impl AsRef<str> for BybitMarket
Sourceimpl Clone for BybitMarket
impl Clone for BybitMarket
Sourcefn clone(&self) -> BybitMarket
fn clone(&self) -> BybitMarket
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BybitMarket
impl Debug for BybitMarket
Sourceimpl<'de> Deserialize<'de> for BybitMarket
impl<'de> Deserialize<'de> for BybitMarket
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for BybitMarket
impl Hash for BybitMarket
Sourceimpl<Server, InstrumentKey, Kind> Identifier<BybitMarket> for Subscription<Bybit<Server>, Keyed<InstrumentKey, MarketDataInstrument>, Kind>
impl<Server, InstrumentKey, Kind> Identifier<BybitMarket> for Subscription<Bybit<Server>, Keyed<InstrumentKey, MarketDataInstrument>, Kind>
fn id(&self) -> BybitMarket
Sourceimpl<Server, Kind> Identifier<BybitMarket> for Subscription<Bybit<Server>, MarketDataInstrument, Kind>
impl<Server, Kind> Identifier<BybitMarket> for Subscription<Bybit<Server>, MarketDataInstrument, Kind>
fn id(&self) -> BybitMarket
Sourceimpl<Server, InstrumentKey, Kind> Identifier<BybitMarket> for Subscription<Bybit<Server>, MarketInstrumentData<InstrumentKey>, Kind>
impl<Server, InstrumentKey, Kind> Identifier<BybitMarket> for Subscription<Bybit<Server>, MarketInstrumentData<InstrumentKey>, Kind>
fn id(&self) -> BybitMarket
Sourceimpl Ord for BybitMarket
impl Ord for BybitMarket
Sourcefn cmp(&self, other: &BybitMarket) -> Ordering
fn cmp(&self, other: &BybitMarket) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for BybitMarket
impl PartialEq for BybitMarket
Sourcefn eq(&self, other: &BybitMarket) -> bool
fn eq(&self, other: &BybitMarket) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for BybitMarket
impl PartialOrd for BybitMarket
Sourceimpl Serialize for BybitMarket
impl Serialize for BybitMarket
impl Eq for BybitMarket
impl StructuralPartialEq for BybitMarket