Module coinbase

Module coinbase 

Coinbase Connector and StreamSelector implementations.

Modules

channel
Defines the type that translates a Barter Subscription into an exchange Connector specific channel used for generating Connector::requests.
market
Defines the type that translates a Barter Subscription into an exchange Connector specific market used for generating Connector::requests.
subscription
Subscription response type and response Validator for Coinbase.
trade
Public trade types for Coinbase.

Structs

Coinbase
Coinbase exchange.

Constants

BASE_URL_COINBASE
Coinbase server base url.

Type Aliases

CoinbaseWsStream
Convenient type alias for a Coinbase ExchangeWsStream using WebSocketSerdeParser.