Module channel

Module channel 

Defines the type that translates a Barter Subscription into an exchange Connector specific channel used for generating Connector::requests.

Structs

CoinbaseChannel
Type that defines how to translate a Barter Subscription into a Coinbase channel to be subscribed to.