pub struct CoinbaseMarket(pub SmolStr);Expand description
Type that defines how to translate a Barter Subscription into a
Coinbase market that can be subscribed to.
See docs: https://docs.cloud.coinbase.com/exchange/docs/websocket-overview#subscribe
Tuple Fields
0: SmolStrTrait Implementations
Sourceimpl AsRef<str> for CoinbaseMarket
impl AsRef<str> for CoinbaseMarket
Sourceimpl Clone for CoinbaseMarket
impl Clone for CoinbaseMarket
Sourcefn clone(&self) -> CoinbaseMarket
fn clone(&self) -> CoinbaseMarket
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CoinbaseMarket
impl Debug for CoinbaseMarket
Sourceimpl<'de> Deserialize<'de> for CoinbaseMarket
impl<'de> Deserialize<'de> for CoinbaseMarket
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for CoinbaseMarket
impl Hash for CoinbaseMarket
Sourceimpl<InstrumentKey, Kind> Identifier<CoinbaseMarket> for Subscription<Coinbase, Keyed<InstrumentKey, MarketDataInstrument>, Kind>
impl<InstrumentKey, Kind> Identifier<CoinbaseMarket> for Subscription<Coinbase, Keyed<InstrumentKey, MarketDataInstrument>, Kind>
fn id(&self) -> CoinbaseMarket
Sourceimpl<Kind> Identifier<CoinbaseMarket> for Subscription<Coinbase, MarketDataInstrument, Kind>
impl<Kind> Identifier<CoinbaseMarket> for Subscription<Coinbase, MarketDataInstrument, Kind>
fn id(&self) -> CoinbaseMarket
Sourceimpl<InstrumentKey, Kind> Identifier<CoinbaseMarket> for Subscription<Coinbase, MarketInstrumentData<InstrumentKey>, Kind>
impl<InstrumentKey, Kind> Identifier<CoinbaseMarket> for Subscription<Coinbase, MarketInstrumentData<InstrumentKey>, Kind>
fn id(&self) -> CoinbaseMarket
Sourceimpl Ord for CoinbaseMarket
impl Ord for CoinbaseMarket
Sourcefn cmp(&self, other: &CoinbaseMarket) -> Ordering
fn cmp(&self, other: &CoinbaseMarket) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for CoinbaseMarket
impl PartialEq for CoinbaseMarket
Sourcefn eq(&self, other: &CoinbaseMarket) -> bool
fn eq(&self, other: &CoinbaseMarket) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for CoinbaseMarket
impl PartialOrd for CoinbaseMarket
Sourceimpl Serialize for CoinbaseMarket
impl Serialize for CoinbaseMarket
impl Eq for CoinbaseMarket
impl StructuralPartialEq for CoinbaseMarket