Module gateio

Module gateio 

GateioSpot, GateioFuturesUsd & GateioFuturesBtc Connector and StreamSelector implementations.

Modules

channel
Defines the type that translates a Barter Subscription into an exchange Connector specific channel used for generating Connector::requests.
future
ExchangeServer and StreamSelector implementations for GateioFutureUsd and GateioFutureBtc.
market
Defines the type that translates a Barter Subscription into an exchange Connector specific market used for generating Connector::requests.
message
Generic GateioMessage<T> type common to GateioSpot, GateioPerpetualUsdt and GateioPerpetualBtc.
option
ExchangeServer and StreamSelector implementations for GateioOptions
perpetual
ExchangeServer and StreamSelector implementations for GateioPerpetualUsdt and GateioPerpetualBtc.
spot
ExchangeServer and StreamSelector implementations for GateioSpot.
subscription
Subscription response type and response Validator common to GateioSpot, GateioPerpetualUsdt and GateioPerpetualBtc.

Structs

Gateio
Generic Gateio<Server> exchange.

Type Aliases

GateiotWsStream
Convenient type alias using WebSocketSerdeParser.