pub struct GateioMarket(pub SmolStr);Expand description
Type that defines how to translate a Barter Subscription into a
Gateio market that can be subscribed to.
See docs: https://www.okx.com/docs-v5/en/#websocket-api-public-channel
Tuple Fields
0: SmolStrTrait Implementations
Sourceimpl AsRef<str> for GateioMarket
impl AsRef<str> for GateioMarket
Sourceimpl Clone for GateioMarket
impl Clone for GateioMarket
Sourcefn clone(&self) -> GateioMarket
fn clone(&self) -> GateioMarket
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GateioMarket
impl Debug for GateioMarket
Sourceimpl<'de> Deserialize<'de> for GateioMarket
impl<'de> Deserialize<'de> for GateioMarket
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for GateioMarket
impl Hash for GateioMarket
Sourceimpl<Server, InstrumentKey, Kind> Identifier<GateioMarket> for Subscription<Gateio<Server>, Keyed<InstrumentKey, MarketDataInstrument>, Kind>
impl<Server, InstrumentKey, Kind> Identifier<GateioMarket> for Subscription<Gateio<Server>, Keyed<InstrumentKey, MarketDataInstrument>, Kind>
fn id(&self) -> GateioMarket
Sourceimpl<Server, Kind> Identifier<GateioMarket> for Subscription<Gateio<Server>, MarketDataInstrument, Kind>
impl<Server, Kind> Identifier<GateioMarket> for Subscription<Gateio<Server>, MarketDataInstrument, Kind>
fn id(&self) -> GateioMarket
Sourceimpl<Server, InstrumentKey, Kind> Identifier<GateioMarket> for Subscription<Gateio<Server>, MarketInstrumentData<InstrumentKey>, Kind>
impl<Server, InstrumentKey, Kind> Identifier<GateioMarket> for Subscription<Gateio<Server>, MarketInstrumentData<InstrumentKey>, Kind>
fn id(&self) -> GateioMarket
Sourceimpl Ord for GateioMarket
impl Ord for GateioMarket
Sourcefn cmp(&self, other: &GateioMarket) -> Ordering
fn cmp(&self, other: &GateioMarket) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for GateioMarket
impl PartialEq for GateioMarket
Sourcefn eq(&self, other: &GateioMarket) -> bool
fn eq(&self, other: &GateioMarket) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for GateioMarket
impl PartialOrd for GateioMarket
Sourceimpl Serialize for GateioMarket
impl Serialize for GateioMarket
impl Eq for GateioMarket
impl StructuralPartialEq for GateioMarket