pub struct KrakenError {
pub message: String,
}Expand description
Kraken generic error message String received over the WebSocket.
Note that since the KrakenError is only made up of a renamed message String field, it can
be used flexible as a KrakenSubResponse::Error
or as a generic error received over the WebSocket while subscriptions are active.
See KrakenMessage for full raw payload examples.
See docs: https://docs.kraken.com/websockets/#errortypes
See docs: https://docs.kraken.com/websockets/#message-subscriptionStatus
Fields
message: StringTrait Implementations
Sourceimpl Clone for KrakenError
impl Clone for KrakenError
Sourcefn clone(&self) -> KrakenError
fn clone(&self) -> KrakenError
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for KrakenError
impl Debug for KrakenError
Sourceimpl<'de> Deserialize<'de> for KrakenError
impl<'de> Deserialize<'de> for KrakenError
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for KrakenError
impl Hash for KrakenError
Sourceimpl Ord for KrakenError
impl Ord for KrakenError
Sourcefn cmp(&self, other: &KrakenError) -> Ordering
fn cmp(&self, other: &KrakenError) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for KrakenError
impl PartialEq for KrakenError
Sourcefn eq(&self, other: &KrakenError) -> bool
fn eq(&self, other: &KrakenError) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for KrakenError
impl PartialOrd for KrakenError
Sourceimpl Serialize for KrakenError
impl Serialize for KrakenError
impl Eq for KrakenError
impl StructuralPartialEq for KrakenError