Module okx

Module okx 

Okx Connector and StreamSelector implementations.

Modules

channel
Defines the type that translates a Barter Subscription into an exchange Connector specific channel used for generating Connector::requests.
market
Defines the type that translates a Barter Subscription into an exchange Connector specific market used for generating Connector::requests.
subscription
Subscription response type and response Validator for Okx.
trade
Public trade types for Okx.

Structs

Okx
Okx exchange.

Constants

BASE_URL_OKX
Okx server base url.
PING_INTERVAL_OKX
Okx server PingInterval duration.

Type Aliases

OkxWsStream
Convenient type alias for an Okx ExchangeWsStream using WebSocketSerdeParser.