Module subscription

Module subscription 

Defines the generic ExchangeSub containing a market and channel combination used by an exchange Connector to build WsMessage subscription payloads.

Structs

ExchangeSub
Defines an exchange specific market and channel combination used by an exchange Connector to build the WsMessage subscription payloads to send to the exchange server.