Module indexed

Module indexed 

Functions

generate_indexed_market_data_subscription_batches
Generates batches of indexed market data Subscriptions from a collection of IndexedInstruments.
index_market_data_subscription_batches
Indexes batches of market data Subscriptions using a collection of IndexedInstruments.
init_indexed_multi_exchange_market_stream
Initialise an indexed DynamicStreams using batches of indexed Subscription batches.