Module reconnect

Module reconnect 

Defines a ReconnectingStream and associated logic for generating an auto reconnecting Stream.

Modules

stream

Enums

Event
ReconnectingStream Event that communicates either Stream::Item, or that the inner Stream is currently reconnecting.