pub struct ReconnectionBackoffPolicy {
pub backoff_ms_initial: u64,
pub backoff_multiplier: u8,
pub backoff_ms_max: u64,
}Expand description
Reconnection backoff policy for a ReconnectingStream::with_reconnect_backoff.
Fields
backoff_ms_initial: u64Initial backoff millisecond duration after the first Stream disconnection.
This value then scales with the backoff_multiplier in the case of repeated failed
Stream reconnection attempts.
backoff_multiplier: u8Scaling factor for the backoff duration in the case of repeated Stream reconnection
attempts.
backoff_ms_max: u64Maximum possible backoff duration between reconnection attempts.
Implementations