pub struct PublicTrade {
pub id: SmolStr,
pub price: Decimal,
pub amount: Decimal,
pub side: Option<Side>,
}Expand description
Normalised Barter PublicTrade model.
Uses SmolStr for id to avoid heap allocation for typical trade IDs
(up to 23 bytes on 64-bit systems are stored inline). Exceptions that
heap-allocate: Bitmex UUIDs (36 bytes), Kraken composite IDs (~34 bytes).
Side Field
The side field indicates the taker/aggressor side of the trade:
Some(Side::Buy): Taker was buying (lifted the ask)Some(Side::Sell): Taker was selling (hit the bid)None: Side information not available from the data source
Crypto exchanges typically provide side info. Equities feeds (e.g., Alpaca IEX/SIP) often do not, as consolidated tape data doesn’t include aggressor information.
Fields
id: SmolStrprice: Decimalamount: Decimalside: Option<Side>Trait Implementations
Sourceimpl Clone for PublicTrade
impl Clone for PublicTrade
Sourcefn clone(&self) -> PublicTrade
fn clone(&self) -> PublicTrade
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PublicTrade
impl Debug for PublicTrade
Sourceimpl<'de> Deserialize<'de> for PublicTrade
impl<'de> Deserialize<'de> for PublicTrade
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<PublicTrade> for DataKind
impl From<PublicTrade> for DataKind
Sourcefn from(value: PublicTrade) -> Self
fn from(value: PublicTrade) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for PublicTrade
impl PartialEq for PublicTrade
Sourcefn eq(&self, other: &PublicTrade) -> bool
fn eq(&self, other: &PublicTrade) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for PublicTrade
impl PartialOrd for PublicTrade
Sourceimpl Serialize for PublicTrade
impl Serialize for PublicTrade
impl StructuralPartialEq for PublicTrade