Module subscription

Module subscription 

Subscription response types and response Validator for Bitfinex.

Structs

BitfinexChannelId
Bitfinex channel identifier that is used to identify the subscription associated with incoming events. See the module level “SubscriptionId” documentation notes for more details.
BitfinexError
Bitfinex error message that is received if a BitfinexSubResponse indicates a WebSocket subscription failure.
BitfinexPlatformStatus
Bitfinex platform status message containing the server we are connecting to, the version of the API, and if it is in maintenance mode.
BitfinexSubResponse
Bitfinex subscription success response variants for each channel.

Enums

BitfinexPlatformEvent
Bitfinex platform event detailing the variants expected to be received while connecting and subscribing.
Status
Bitfinex platform Status indicating if the API is in maintenance mode.