Option Greeks data model for options analytics. Option Greeks subscription type.
This module defines the OptionGreeks data type for option analytics
(delta, gamma, theta, vega, implied volatility).
Unlike other subscription types in this module, Greeks are typically computed by the exchange/broker from live market data rather than being raw market data themselves.
Structs
- Option
Greeks - Option Greeks values.